@@ -1466,7 +1466,7 @@ class Molecule:
         fragments = nx.connected_components(self.bonds)
         return [list(f) for f in list(fragments)]
 
-    def limit_solvent_shell(self, solute=0, num_atoms=0, num_solvents=10):
+    def limit_solvent_shell(self, solute=0, num_atoms=0, num_solvents=10, distance_from_atom=None, return_idxs=False):
         """
         Automatically detects solvent molecules and removes them until you have a set number of solvents or atoms.
 
@@ -1476,6 +1476,9 @@ class Molecule:
             solute (int): which fragment is the solute, 0-indexed
             num_atoms (int): remove atoms until there are this number (modulo the size of a solvent molecule)
             num_solvents (int): remove solvent molecules until there are this number
+            distance_from_atom (int): if you want to find molecules closest to a given atom in the solute, specify the atom number here.
+                if this atom is not in the solute fragment, an exception will be raised.
+            return_idxs (bool): if True, indices of atoms that would be in the new molecule are returned. no change is made to ``self``.
 
         Returns:
             new ``Molecule`` object
@@ -1484,7 +1487,11 @@ class Molecule:
         assert isinstance(num_solvents, int)
 
         fragments = self.get_components()
-        solute_x = self.geometry[fragments[0]].view(np.ndarray)
+        solute_x = self.geometry[fragments[solute]].view(np.ndarray)
+
+        if distance_from_atom:
+            assert distance_from_atom in fragments[solute], f"{distance_from_atom} is not in the solute fragment"
+            solute_x = self.geometry[[distance_from_atom]].view(np.ndarray)
 
         distances = np.zeros(shape=len(fragments))
         for i, f in enumerate(fragments):
@@ -1512,10 +1519,14 @@ class Molecule:
             current_num_solvents += -1
 
             if current_num_atoms <= num_atoms or num_solvents == current_num_solvents:
-                #### have to remove in reverse direction for indexing consistency
-                for j in sorted(to_remove, reverse=True):
-                    mol.remove_atom(j)
-                return mol
+                if return_idxs:
+                    all_idxs = set(range(1,self.num_atoms()))
+                    return list(all_idxs - set(to_remove))
+                else:
+                    #### have to remove in reverse direction for indexing consistency
+                    for j in sorted(to_remove, reverse=True):
+                        mol.remove_atom(j)
+                    return mol
 
     def center_periodic(self, center, side_length):
         """
@@ -1632,23 +1643,42 @@ class Molecule:
         symbols = {z: get_symbol(z) for z in set(self.atomic_numbers)}
         return [symbols[z] for z in self.atomic_numbers]
 
-    def optimize(self, inplace=True, nprocs=1):
+    def optimize(self, inplace=True, nprocs=1, return_energy=False):
         """
         Optimize molecule at the GFN2-xtb level of theory.
 
         Args:
             inplace (Bool): whether or not to return a new molecule or simply modify ``self.geometry``
             nprocs (int): number of processors to use
+            return_energy (Bool): whether to return energy or not
         """
         import cctk.optimize as opt
         assert isinstance(nprocs, int), "nprocs must be int!"
-        optimized = opt.optimize_molecule(self, nprocs=nprocs)
+        optimized, energy = opt.optimize_molecule(self, nprocs=nprocs, return_energy=True)
 
         if inplace:
             self.geometry = optimized.geometry
-            return self
+            if return_energy:
+                return self, energy
+            else:
+                return self
         else:
-            return optimized
+            if return_energy:
+                return optimized, energy
+            else:
+                return optimized
+
+    def compute_energy(self, nprocs=1):
+        """
+        Compute energy of molecule at the GFN2-xtb level of theory.
+
+        Args:
+            nprocs (int): number of processors to use
+        """
+        import cctk.optimize as opt
+        assert isinstance(nprocs, int), "nprocs must be int!"
+        energy = opt.get_energy(self, nprocs=nprocs)
+        return energy
 
     def csearch(self, nprocs=1, constraints=[], logfile=None, noncovalent=False, use_tempdir=True):
         """
@@ -1676,3 +1706,45 @@ class Molecule:
         for i in range(self.num_atoms()):
             result.append(len(self.get_adjacent_atoms(i)))
         return result
+
+    def atoms_moving_in_imaginary(self, max_num=5, percent_cutoff=0.03, return_string=False):
+        """
+        Returns atoms moving in imaginary, ranked by how much they're moving.
+
+        Args:
+            max_num (int): how many atoms max to return
+            percent_cutoff (float): threshold for what percent of total TS movement qualifies as "movement"
+            return_string (bool): whether or not to return a formatted string report
+
+        Returns:
+            list of atomic numbers or string
+        """
+        imaginary = 0
+        ts_mode = None
+        for mode in self.vibrational_modes:
+            if mode.frequency < imaginary:
+                imaginary = mode.frequency
+                ts_mode = mode
+
+        if ts_mode is None:
+            if return_string:
+                return ""
+            else:
+                return None
+
+        displacements = np.linalg.norm(ts_mode.displacements.view(np.ndarray), axis=-1)
+
+        atoms_ranked = np.argsort(displacements)[::-1] + 1
+        percent_movement = np.sort(displacements)[::-1] / np.sum(displacements)
+
+        return_list, string = list(), ""
+        for atom, percent in zip(atoms_ranked, percent_movement):
+            if percent > percent_cutoff and len(return_list) <= max_num:
+                return_list.append(atom)
+                string += f"{self.atom_string(atom)} ({percent:.1%}), "
+            else:
+                if return_string:
+                    return string[:-2]
+                else:
+                    return return_list
+
