@@ -3,7 +3,7 @@ Functions to assist in optimizing structures.
 """
 
 import numpy as np
-import os, tempfile, shutil, re, logging
+import os, tempfile, shutil, re
 import cctk
 import subprocess as sp
 
@@ -41,9 +41,28 @@ def optimize_molecule(molecule, method=Methods.GFN2_XTB, nprocs=1, return_energy
     assert isinstance(method, Methods), "need a valid molecule!"
 
     if method is Methods.GFN2_XTB:
-        return run_xtb(molecule, nprocs=nprocs, return_energy=return_energy)
+        return run_xtb(molecule, nprocs=nprocs, return_energy=return_energy, opt=True)
 
-def run_xtb(molecule, nprocs=1, return_energy=False):
+def get_energy(molecule, method=Methods.GFN2_XTB, nprocs=1):
+    """
+    Dispatcher method to connect method to molecule.
+
+    Args:
+        molecule (cctk.Molecule):
+        method (Methods):
+        nprocs (int): number of cores to employ
+
+    Returns:
+        energy
+    """
+    assert isinstance(molecule, cctk.Molecule), "need a valid molecule!"
+    assert isinstance(method, Methods), "need a valid molecule!"
+
+    if method is Methods.GFN2_XTB:
+        _, energy = run_xtb(molecule, nprocs=nprocs, return_energy=True, opt=False)
+        return energy
+
+def run_xtb(molecule, nprocs=1, return_energy=False, opt=False):
     """
     Run ``xtb`` in a temporary directory and return the output molecule.
     """
@@ -55,9 +74,12 @@ def run_xtb(molecule, nprocs=1, return_energy=False):
     command = f"xtb --gfn 2 --chrg {molecule.charge} --uhf {molecule.multiplicity - 1}"
     if nprocs > 1:
         command += f" --parallel {nprocs}"
-    command += " xtb-in.xyz --opt tight &> xtb-out.out"
 
-    output_mol, energy, gradient = None, None, None
+    if opt:
+        command += " xtb-in.xyz --opt tight &> xtb-out.out"
+    else:
+        command += " xtb-in.xyz &> xtb-out.out"
+
     try:
         os.environ["OMP_NUM_THREADS"] = str(nprocs)
         os.environ["MKL_NUM_THREADS"] = str(nprocs)
@@ -65,19 +87,24 @@ def run_xtb(molecule, nprocs=1, return_energy=False):
             cctk.XYZFile.write_molecule_to_file(f"{tmpdir}/xtb-in.xyz", molecule)
             result = sp.run(command, stdout=sp.PIPE, stderr=sp.PIPE, cwd=tmpdir, shell=True)
 
-            output_mol = cctk.XYZFile.read_file(f"{tmpdir}/xtbopt.xyz").molecule
-            energy_file = cctk.File.read_file(f"{tmpdir}/xtbopt.log")
+            output_mol, energy_file = None, None
+            if opt:
+                output_mol = cctk.XYZFile.read_file(f"{tmpdir}/xtbopt.xyz").molecule
+                energy_file = cctk.File.read_file(f"{tmpdir}/xtbopt.log")
+            else:
+                print("Need to read energy from xtb-out.out!")
+                raise NotImplementedError
 
             fields = energy_file[1].split()
             energy, gradient = float(fields[1]), float(fields[3])
+
+            if return_energy:
+                return output_mol, energy
+            else:
+                return output_mol
     except Exception as e:
         raise ValueError(f"Error running xtb:\n{e}")
 
-    if return_energy:
-        return output_mol, energy
-    else:
-        return output_mol
-
 def csearch(use_tempdir=True, **kwargs):
     """
     Run a conformational search on a molecule using ``crest``.
@@ -85,7 +112,6 @@ def csearch(use_tempdir=True, **kwargs):
     Args:
         molecule (cctk.Molecule): molecule of interest
         constraints (list): list of atom numbers to constrain
-        rotamers (bool): return all rotamers or group into distinct conformers
         nprocs (int): number of processors to use
         noncovalent (Bool): whether or not to use non-covalent settings
         logfile (str): file to write ongoing ``crest`` output to
@@ -118,28 +144,25 @@ def _do_csearch(molecule, nprocs, logfile, noncovalent, directory, constraints):
     if noncovalent:
         nci = "-nci"
 
+    command = None
     if constraints is not None:
         assert isinstance(constraints, list)
         assert all(isinstance(n, int) for n in constraints)
         command = f"crest xtb-in.xyz --constrain {','.join([str(c) for c in constraints])}"
         result = sp.run(command, stdout=sp.PIPE, stderr=sp.PIPE, cwd=directory, shell=True)
         result.check_returncode()
-
-    command = f"crest xtb-in.xyz --chrg {molecule.charge} --uhf {molecule.multiplicity - 1} -T {nprocs} {nci}"
+        command = f"crest xtb-in.xyz --chrg {molecule.charge} -cinp .xcontrol.sample --uhf {molecule.multiplicity - 1} -T {nprocs} {nci}"
+    else:
+        command = f"crest xtb-in.xyz --chrg {molecule.charge} --uhf {molecule.multiplicity - 1} -T {nprocs} {nci}"
 
     if logfile:
         with open(logfile, "w") as f:
             result = sp.run(command, stdout=f, stderr=f, cwd=directory, shell=True)
     else:
         result = sp.run(command, stdout=sp.PIPE, stderr=sp.PIPE, cwd=directory, shell=True)
-
     result.check_returncode()
 
-    if rotamers:
-        ensemble = cctk.XYZFile.read_ensemble(f"{directory}/crest_rotamers.xyz")
-    else:
-        ensemble = cctk.XYZFile.read_ensemble(f"{directory}/crest_conformers.xyz")
-
+    ensemble = cctk.XYZFile.read_ensemble(f"{directory}/crest_conformers.xyz")
     return ensemble
 
 
