@@ -53,6 +53,8 @@ def read_nmr_shifts(blocks, num_atoms):
 
     if len(shieldings) is not 0:
         assert len(shieldings) == num_atoms, f"Expected {num_atoms} shieldings but found {len(shieldings)}!"
+        for shielding, tensor in zip(shieldings, tensors):
+            assert 0.01 > abs(np.trace(tensor)/3 - shielding)
         return np.asarray(shieldings), tensors
     else:
         #### we can catch this problem later if the file is finished
@@ -78,7 +80,7 @@ def split_link1(filename):
 
     return link1_blocks[1:] #### the first block is just a few lines
 
-def read_file_fast(file_text, filename, link1idx, max_len=10000, extended_opt_info=False):
+def read_file_fast(file_text, filename, link1idx, max_len=20000, extended_opt_info=False):
 
     #### "Make your bottleneck routines fast, everything else clear" - M. Scott Shell, UCSB
     #### Welcome to the fast part!
@@ -102,6 +104,10 @@ def read_file_fast(file_text, filename, link1idx, max_len=10000, extended_opt_in
         "Frequencies",
         "Temperature", #15
         "Isotropic",
+        "EUMP2",
+        "EUMP3",
+        "UMP4(SDTQ)",
+        "Wavefunction amplitudes converged", #20
     ]
 
     #### And here are the blocks of text
@@ -109,7 +115,7 @@ def read_file_fast(file_text, filename, link1idx, max_len=10000, extended_opt_in
 
     blocks = [
         ["#p", "----", 1],
-        ["l101.exe", "Symbolic Z-matrix", 1],
+        ["/99;", "Symbolic Z-matrix", 1],
         ["The following ModRedundant input section", "\n \n", 1],
         [
             ["Input orientation", "Standard orientation", "Cartesian Coordinates"],
@@ -203,7 +209,7 @@ def read_file_fast(file_text, filename, link1idx, max_len=10000, extended_opt_in
     del file_text # here, have your RAM back!
 
     if len(block_matches[1]) == 0:
-        raise ValueError(f"Can't find a title block - something is wrong with {filename}!")
+        raise ValueError(f"Can't find a title block - something is wrong with {filename}! (cctk requires Gaussian output files to have been run in ``#p`` verbose mode)")
 
     #### and from here, we're off to the races!
     n, g = parse_geometry(block_matches[3])
@@ -213,6 +219,18 @@ def read_file_fast(file_text, filename, link1idx, max_len=10000, extended_opt_in
     charge, multip = parse_charge_multiplicity(word_matches[4])
     bonds = parse_bonds(block_matches[5])
 
+    # post-HF methods give weird energies
+    if re.search("mp2", route_card, re.IGNORECASE):
+        energies = parse_mp2_energies(word_matches[17])
+    elif re.search("mp3", route_card, re.IGNORECASE):
+        energies = parse_mp3_energies(word_matches[18])
+    elif re.search("mp4", route_card, re.IGNORECASE):
+        energies = parse_mp4_energies(word_matches[19])
+    elif re.search("ccsd", route_card, re.IGNORECASE):
+        energies = parse_cc_energies(word_matches[20])
+    elif re.search("cisd", route_card, re.IGNORECASE):
+        energies = parse_ci_energies(word_matches[20])
+
     f = cctk.GaussianFile(job_types=job_types, route_card=route_card, link0=link0, footer=footer, success=success, elapsed_time=elapsed_time, title=title)
 
     molecules = [None] * len(g)
@@ -330,9 +348,10 @@ def read_file_fast(file_text, filename, link1idx, max_len=10000, extended_opt_in
             properties[-1]["hirshfeld_spins"] = spins
 
     try:
-        charges, dipole = parse_charges_dipole(block_matches[9], block_matches[10])
+        charges, dipole, dipole_v = parse_charges_dipole(block_matches[9], block_matches[10])
         properties[-1]["mulliken_charges"] = charges
         properties[-1]["dipole_moment"] = dipole
+        properties[-1]["dipole_vector"] = dipole_v
     except Exception as e:
         pass
 
@@ -367,7 +386,9 @@ def parse_header_footer(route_block, title_block, footer_block, link0_block):
     title = ""
     job_types = []
 
-    title = title_block[0].split("\n")[2].strip()
+    # 2 lines before 'Symbolic Z Matrix'
+    title = title_block[0].split("\n")[-3].strip()
+
     for line in route_block[0].split("\n"):
         route_card += line.lstrip()
 
@@ -445,7 +466,7 @@ def extract_parameter(lines, position, cast_to_float=True):
         if cast_to_float:
             try:
                 vals.append(float(pieces[position]))
-            except:
+            except Exception as e:
                 #### sometimes RMS Force comes thru as "******" for some reason
                 vals.append(0)
         else:
@@ -466,6 +487,7 @@ def parse_forces(force_block):
 def parse_charges_dipole(mulliken_block, dipole_block):
     charges = []
     dipole = 0
+    dipole_v = np.zeros(shape=3)
 
     for line in mulliken_block[0].split("\n")[2:]:
         fields = re.split(" +", line)
@@ -479,10 +501,13 @@ def parse_charges_dipole(mulliken_block, dipole_block):
         fields = list(filter(None, fields))
 
         if len(fields) == 8:
+            dipole_v[0] = float(fields[1])
+            dipole_v[1] = float(fields[3])
+            dipole_v[2] = float(fields[5])
             dipole = float(fields[7])
             break
 
-    return cctk.OneIndexedArray(charges), dipole
+    return cctk.OneIndexedArray(charges), dipole, dipole_v
 
 def parse_hirshfeld(hirshfeld_block):
     charges = []
@@ -505,10 +530,11 @@ def parse_modes(freq_block, num_atoms, hpmodes=False):
     freqs = list()
     masses = list()
     force_ks = list()
+    intensities = list()
     displacements = list()
 
     if len(freq_block) == 0:
-        return None
+        return list()
 
     chunks = freq_block[0].split("Freq")
 
@@ -534,6 +560,7 @@ def parse_modes(freq_block, num_atoms, hpmodes=False):
 
             masses += list(filter(None, re.split(" +", lines[1])))[3:]
             force_ks += list(filter(None, re.split(" +", lines[2])))[3:]
+            intensities += list(filter(None, re.split(" +", lines[3])))[3:]
 
             for line in lines[6:]:
                 fields = re.split(" +", line)
@@ -552,11 +579,12 @@ def parse_modes(freq_block, num_atoms, hpmodes=False):
                 displacements.append(d.view(cctk.OneIndexedArray))
 
         else:
-            current_displacements = [list() for x in re.split(" +", lines[0])[2:]]
+            current_displacements = [list() for _ in re.split(" +", lines[0])[2:]]
 
             freqs += re.split(" +", lines[0])[2:]
             masses += re.split(" +", lines[1])[4:]
             force_ks += re.split(" +", lines[2])[4:]
+            intensities += re.split(" +", lines[3].rstrip())[4:]
 
             for line in lines[5:]:
                 fields = re.split(" +", line)
@@ -573,22 +601,22 @@ def parse_modes(freq_block, num_atoms, hpmodes=False):
                 if len(current_displacements) > 2:
                     current_displacements[2].append([float(x) for x in fields[8:11]])
 
-
             for d in current_displacements:
                 displacements.append(cctk.OneIndexedArray(d))
 
     freqs = [float(x) for x in freqs]
     masses = [float(x) for x in masses]
     force_ks = [float(x) for x in force_ks]
+    intensities = [float(x) for x in intensities]
 
     assert len(freqs) == len(masses)
     assert len(freqs) == len(force_ks)
     assert len(freqs) == len(displacements)
 
     modes = list()
-    for f, m, k, d in zip(freqs, masses, force_ks, displacements):
+    for f, m, k, i, d in zip(freqs, masses, force_ks, intensities, displacements):
         k *= 143.9326 # mdyne Å**-1 to kcal/mol Å**-2
-        modes.append(cctk.VibrationalMode(frequency=f, reduced_mass=m, force_constant=k, displacements=d))
+        modes.append(cctk.VibrationalMode(frequency=f, reduced_mass=m, force_constant=k, intensity=i, displacements=d))
 
     return modes
 
@@ -663,3 +691,42 @@ def read_j_couplings(lines, n_atoms):
             raise ValueError("impossible")
 
     return couplings
+
+def parse_mp2_energies(lines):
+    energies = []
+    for line in lines:
+        pieces = list(filter(None, line.split(" ")))
+        energy_str = pieces[5]
+        energy_str = re.sub("D", "E", energy_str)
+        energies.append(float(energy_str))
+    return energies
+
+def parse_mp3_energies(lines):
+    energies = []
+    for line in lines:
+        pieces = list(filter(None, line.split(" ")))
+        energy_str = pieces[3]
+        energy_str = re.sub("D", "E", energy_str)
+        energies.append(float(energy_str))
+    return energies
+
+def parse_mp4_energies(lines):
+    energies = []
+    for line in lines:
+        pieces = list(filter(None, line.split(" ")))
+        energy_str = pieces[3]
+        energy_str = re.sub("D", "E", energy_str)
+        energies.append(float(energy_str))
+    return energies
+
+def parse_cc_energies(lines):
+    energies = []
+    for line in lines:
+        pieces = list(filter(None, line.split(" ")))
+        energy_str = pieces[4]
+        energy_str = re.sub("D", "E", energy_str)
+        energies.append(float(energy_str))
+    return energies
+
+def parse_ci_energies(lines):
+    return parse_cc_energies(lines)
