@@ -51,6 +51,10 @@ class XYZFile(cctk.File):
             try:
                 if re.match("[0-9]", pieces[0]):
                     atomic_numbers[index] = int(pieces[0])
+                elif re.match("([A-Za-z])+([0-9])+", pieces[0]):
+                    # mdtraj writes in this format, for some reason
+                    m = re.match("([A-Za-z])+([0-9])+", pieces[0])
+                    atomic_numbers[index] = int(get_number(m.group(1)))
                 else:
                     atomic_numbers[index] = int(get_number(pieces[0]))
                 geometry[index][0] = float(pieces[1])
@@ -64,7 +68,7 @@ class XYZFile(cctk.File):
         return XYZFile(molecule, title)
 
     @classmethod
-    def write_molecule_to_file(cls, filename, molecule, title="title"):
+    def write_molecule_to_file(cls, filename, molecule, title="title", append=False):
         """
         Write an ``.xyz`` file, using object attributes.
 
@@ -72,6 +76,7 @@ class XYZFile(cctk.File):
             filename (str): path to the new file
             molecule (Molecule): molecule to write
             title (str): title of file
+            append (Bool): whether or not to append to file
         """
         assert isinstance(molecule, cctk.Molecule), "molecule is not a valid Molecule object!"
 
@@ -82,7 +87,10 @@ class XYZFile(cctk.File):
             line = molecule.get_vector(index)
             text += f"{get_symbol(Z):>2}       {line[0]:>13.8f} {line[1]:>13.8f} {line[2]:>13.8f}\n"
 
-        super().write_file(filename, text)
+        if append:
+            super().append_to_file(filename, text)
+        else:
+            super().write_file(filename, text)
 
     def write_file(self, filename):
         """
@@ -133,5 +141,21 @@ class XYZFile(cctk.File):
 
         return ensemble
 
+    @classmethod
+    def write_ensemble_to_file(cls, filename, ensemble, title=None):
+        """
+        Write a ``cctk.Ensemble`` to a single ``.xyz`` file. Can be viewed in MOLDEN.
+        """
+        assert isinstance(ensemble, cctk.Ensemble), f"ensemble {ensemble} is not a cctk.Ensemble"
 
+        if title is None:
+            title = "title"
+        if isinstance(title, str):
+            title = [title for _ in range(len(ensemble))]
+        assert len(title) == len(ensemble)
 
+        for idx, (molecule, title) in enumerate(zip(ensemble._items, title)):
+            if idx == 0:
+                cls.write_molecule_to_file(filename, molecule, title=title, append=False)
+            else:
+                cls.write_molecule_to_file(filename, molecule, title=title, append=True)
